@@ -1,21 +1,14 @@
-/* ftp.c -- low(er) level FTP stuff
- * 
- * This file is part of Yafc, an ftp client.
- * This program is Copyright (C) 1998-2001 martin HedenfaLk
- * 
+/* $Id: ftp.c,v 1.18 2001/05/12 18:44:04 mhe Exp $
+ *
+ * ftp.c -- low(er) level FTP stuff
+ *
+ * Yet Another FTP Client
+ * Copyright (C) 1998-2001, Martin Hedenfalk <mhe@stacken.kth.se>
+ *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- * 
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * (at your option) any later version. See COPYING for more details.
  */
 
 #include "syshdr.h"
@@ -24,6 +17,8 @@
 #include "xmalloc.h"
 #include "strq.h"
 #include "gvars.h"
+#include "ssh_cmd.h"
+#include "sftp-common.h"
 
 /* in cmd.c */
 void exit_yafc(void);
@@ -59,6 +54,7 @@ Ftp *ftp_create(void)
 /*	ftp->out_buffer = 0;*/
 #endif
 	ftp->LIST_type = ltUnknown;
+	ftp->ssh_id = 1;
 
 	return ftp;
 }
@@ -181,6 +177,15 @@ void ftp_reset_vars(void)
 	host_destroy(ftp->host);
 	ftp->host = 0;
 
+	if(ftp->ssh_pid) {
+		ftp->ssh_pid = 0;
+		close(ftp->ssh_in);
+		close(ftp->ssh_out);
+		ftp->ssh_id = 0;
+	}
+	xfree(ftp->ssh_args);
+	ftp->ssh_args = 0;
+
 	url_destroy(ftp->url);
 	ftp->url = 0;
 
@@ -254,11 +259,12 @@ static RETSIGTYPE ftp_open_handler(int signum)
 	ftp_longjmp(open_timeout_jmp, 1);
 }
 
-int ftp_open_url(url_t *urlp)
+int ftp_open_url(url_t *urlp, bool reset_vars)
 {
 	bool use_proxy;
 
-	ftp_reset_vars();
+	if(reset_vars)
+		ftp_reset_vars();
 
 #ifdef HAVE_POSIX_SIGSETJMP
 	if(sigsetjmp(open_timeout_jmp, 1))
@@ -276,16 +282,17 @@ int ftp_open_url(url_t *urlp)
 
 	use_proxy = (proxy_type(urlp) != 0);
 
-	if(urlp->protocol && strcmp(urlp->protocol, "ftp") != 0) {
-		ftp_err(_("Sorry, don't know how to handle your '%s' protocol\n"
-				  "trying 'ftp' instead...\n"),
-				urlp->protocol);
-		url_setprotocol(urlp, 0);
-	}
-
 	ftp_err(_("Looking up %s... "),
 			use_proxy ? gvProxyUrl->hostname : urlp->hostname);
 
+	/* Set the default port (22) for SSH if no port is specified. We
+	 * need to do this here, 'cause host_lookup() sets it to 21
+	 * (default port for vanilla FTP)
+	 */
+	if(urlp->protocol && strcmp(urlp->protocol, "ssh") == 0
+		&& urlp->port == -1)
+		urlp->port = 22; /* default SSH port */
+
 	ftp->host = host_create(use_proxy ? gvProxyUrl : urlp);
 
 	if(host_lookup(ftp->host) != 0) {
@@ -298,6 +305,20 @@ int ftp_open_url(url_t *urlp)
 
 	fprintf(stderr, "\r");
 	ftp_trace("\n");
+
+	if(urlp->protocol && strcmp(urlp->protocol, "ssh") == 0) {
+		int ret = ssh_open_url(urlp);
+		alarm(0);
+		return ret;
+	}
+
+	if(urlp->protocol && strcmp(urlp->protocol, "ftp") != 0) {
+		ftp_err(_("Sorry, don't know how to handle your '%s' protocol\n"
+				  "trying 'ftp' instead...\n"),
+				urlp->protocol);
+		url_setprotocol(urlp, 0);
+	}
+
 	if(use_proxy) {
 		ftp_err(_("Connecting to proxy %s (%s) at port %d...\n"),
 				ftp->host->ohostname, ftp->host->ipnum,
@@ -355,7 +376,27 @@ int ftp_open(const char *host)
 {
 	url_t *url;
 	url = url_init(host);
-	return ftp_open_url(ftp->url);
+	return ftp_open_url(ftp->url, true);
+}
+
+int ftp_reopen(void)
+{
+	if(ftp && ftp->url) {
+		url_t *u = url_clone(ftp->url);
+		int r;
+
+		url_setdirectory(u, ftp->curdir);
+
+		r = ftp_open_url(u, false);
+		if(r == 0) {
+			r = ftp_login(u->username, gvAnonPasswd);
+		} else
+			ftp_close();
+		url_destroy(u);
+		return r;
+	}
+
+	return -1;
 }
 
 /* reads one line from server into ftp->reply
@@ -456,6 +497,9 @@ const char *ftp_getreply(bool withcode)
 {
 	char *r = ftp->reply;
 
+	if(ftp->ssh_pid)
+		return fx2txt(ftp->ssh_last_status);
+
 	if(withcode)
 		return r;
 
@@ -560,13 +604,14 @@ static void ftp_print_cmd(const char *cmd, va_list ap)
 	}
 }
 
-/* sends a ftp command on the control channel
- * returns reply statuc code on success or -1 on error
+/* sends an FTP command on the control channel
+ * returns reply status code on success or -1 on error
  */
 int ftp_cmd(const char *cmd, ...)
 {
 	va_list ap;
 	int resp;
+	bool recon = false;
 
 	if(!sock_connected(ftp->ctrl)) {
 		ftp_err(_("No control connection\n"));
@@ -577,6 +622,8 @@ int ftp_cmd(const char *cmd, ...)
 
 	ftp_set_abort_handler();
 
+  ugly:
+
 	va_start(ap, cmd);
 	sock_krb_vprintf(ftp->ctrl, cmd, ap);
 	sock_printf(ftp->ctrl, "\r\n");
@@ -605,18 +652,29 @@ int ftp_cmd(const char *cmd, ...)
 	resp = ftp_read_reply();
 	ftp_set_close_handler();
 	if(resp == 421) { /* server is closing control connection! */
-		ftp_err(_("Server closed control connection?\n"));
-/*		ftp_close();*/
-		ftp->fullcode = 421;
-		ftp->code = 4;
-		return -1;
+		ftp_err(_("Server closed control connection\n"));
+		if(gvAutoReconnect && strcasecmp(cmd, "QUIT") != 0) {
+			if(recon) {
+				ftp_err(_("Reconnect failed\n"));
+			} else {
+				ftp_err(_("Automatic reconnect...\n"));
+				ftp_reopen();
+				recon = true;
+				goto ugly;
+			}
+		} else {
+			/*		ftp_close();*/
+			ftp->fullcode = 421;
+			ftp->code = 4;
+			return -1;
+		}
 	}
 	return resp;
 }
 
 void ftp_quit(void)
 {
-	if(ftp_connected()) {
+	if(ftp_connected() && !ftp->ssh_pid) {
 		ftp_reply_timeout(10);
 		ftp_set_tmp_verbosity(vbCommand);
 		ftp_cmd("QUIT");
@@ -634,7 +692,7 @@ int ftp_get_verbosity(void)
 void ftp_set_verbosity(int verbosity)
 {
 	ftp->verbosity = verbosity;
-	ftp->tmp_verbosity = vbUnset; 
+	ftp->tmp_verbosity = vbUnset;
 }
 
 void ftp_set_tmp_verbosity(int verbosity)
@@ -688,7 +746,7 @@ static int get_password(url_t *url, const char *anonpass, bool isproxy)
 
 		if(url_isanon(url) && isproxy == false) {
 			char *prompt;
-			
+
 			e = 0;
 			if(ftp->getuser_hook) {
 				if(anonpass && isproxy == false)
@@ -708,7 +766,7 @@ static int get_password(url_t *url, const char *anonpass, bool isproxy)
 			e = ftp->getpass_hook(isproxy ? _("Proxy password: ")
 								  : _("password: "));
 		}
-		
+
 		if(!e) {
 			fprintf(stderr, _("You loose\n"));
 			return -1;
@@ -719,6 +777,8 @@ static int get_password(url_t *url, const char *anonpass, bool isproxy)
 	return 0;
 }
 
+#if defined(KRB4) || defined(KRB5)
+
 static const char *secext_name(const char *mech)
 {
 	static struct {
@@ -754,6 +814,8 @@ static bool mech_unsupported(const char *mech)
 	return false;
 }
 
+#endif /* KRB4 or KRB5 */
+
 int ftp_login(const char *guessed_username, const char *anonpass)
 {
 	int ptype, r;
@@ -765,6 +827,10 @@ int ftp_login(const char *guessed_username, const char *anonpass)
 	if(!ftp->url)
 		return -1;
 
+	if(ftp->ssh_pid)
+		/* login authentication is performed by the ssh program */
+		return 0;
+
 	ptype = proxy_type(ftp->url);
 	if(purl) {
 		url_destroy(purl);
@@ -834,7 +900,7 @@ int ftp_login(const char *guessed_username, const char *anonpass)
 					  " and password ***\n"));
 	}
 #endif
-	
+
 	if(url_isanon(ftp->url))
 		fprintf(stderr, _("logging in anonymously...\n"));
 	ftp_set_tmp_verbosity(ftp->url->password ? vbError : vbCommand);
@@ -917,7 +983,7 @@ int ftp_login(const char *guessed_username, const char *anonpass)
 		  case 5:
 			ftp_cmd("PASS %s@%s", ftp->url->password, purl->password);
 			break;
-			
+
 		}
 	}
 
@@ -965,11 +1031,14 @@ bool ftp_loggedin(void)
 
 bool ftp_connected(void)
 {
-	return (ftp->connected && sock_connected(ftp->ctrl));
+	return (ftp->connected && (sock_connected(ftp->ctrl) || ftp->ssh_pid));
 }
 
 char *ftp_getcurdir(void)
 {
+	if(ftp->ssh_pid)
+		return ssh_getcurdir();
+
 	ftp_set_tmp_verbosity(vbNone);
 	ftp_cmd("PWD");
 	if(ftp->code == ctComplete) {
@@ -991,7 +1060,7 @@ char *ftp_getcurdir(void)
 	return xstrdup("CWD?");
 }
 
-static void ftp_update_curdir_x(const char *p)
+void ftp_update_curdir_x(const char *p)
 {
 	xfree(ftp->prevdir);
 	ftp->prevdir = ftp->curdir;
@@ -1008,6 +1077,9 @@ static void ftp_update_curdir(void)
 
 int ftp_chdir(const char *path)
 {
+	if(ftp->ssh_pid)
+		return ssh_chdir(path);
+
 	ftp_set_tmp_verbosity(vbCommand);
 	ftp_cmd("CWD %s", path);
 	if(ftp->code == ctComplete) {
@@ -1043,6 +1115,9 @@ int ftp_chdir(const char *path)
 
 int ftp_cdup(void)
 {
+	if(ftp->ssh_pid)
+		return ssh_cdup();
+
 	ftp_set_tmp_verbosity(vbCommand);
 	ftp_cmd("CDUP");
 	if(ftp->code == ctComplete) {
@@ -1054,7 +1129,12 @@ int ftp_cdup(void)
 
 static int ftp_mkdir_verb(const char *path, verbose_t verb)
 {
-	char *p = xstrdup(path);
+	char *p;
+
+	if(ftp->ssh_pid)
+		return ssh_mkdir_verb(path, verb);
+
+	p = xstrdup(path);
 	stripslash(p);
 
 	ftp_set_tmp_verbosity(verb);
@@ -1074,6 +1154,9 @@ int ftp_rmdir(const char *path)
 {
 	char *p;
 
+	if(ftp->ssh_pid)
+		return ssh_rmdir(path);
+
 	p = xstrdup(path);
 	stripslash(p);
 	ftp_set_tmp_verbosity(vbError);
@@ -1088,6 +1171,9 @@ int ftp_rmdir(const char *path)
 
 int ftp_unlink(const char *path)
 {
+	if(ftp->ssh_pid)
+		return ssh_unlink(path);
+
 	ftp_cmd("DELE %s", path);
 	if(ftp->code == ctComplete) {
 		ftp_cache_flush_mark_for(path);
@@ -1098,6 +1184,9 @@ int ftp_unlink(const char *path)
 
 int ftp_chmod(const char *path, const char *mode)
 {
+	if(ftp->ssh_pid)
+		return ssh_chmod(path, mode);
+
 	if(ftp->has_site_chmod_command) {
 		ftp_set_tmp_verbosity(vbNone);
 		ftp_cmd("SITE CHMOD %s %s", mode, path);
@@ -1120,6 +1209,9 @@ void ftp_reply_timeout(unsigned int secs)
 
 int ftp_idle(const char *idletime)
 {
+	if(ftp->ssh_pid)
+		return ssh_idle(idletime);
+
 	if(!ftp->has_site_idle_command) {
 		ftp_err(_("Server doesn't support SITE IDLE\n"));
 		return -1;
@@ -1138,6 +1230,9 @@ int ftp_idle(const char *idletime)
 
 int ftp_noop(void)
 {
+	if(ftp->ssh_pid)
+		return ssh_noop();
+
 	ftp_set_tmp_verbosity(vbCommand);
 	ftp_cmd("NOOP");
 	return ftp->code == ctComplete ? 0 : -1;
@@ -1145,6 +1240,9 @@ int ftp_noop(void)
 
 int ftp_help(const char *arg)
 {
+	if(ftp->ssh_pid)
+		return ssh_help(arg);
+
 	ftp_set_tmp_verbosity(vbCommand);
 	if(arg)
 		ftp_cmd("HELP %s", arg);
@@ -1157,6 +1255,9 @@ unsigned long ftp_filesize(const char *path)
 {
 	unsigned long ret;
 
+	if(ftp->ssh_pid)
+		return ssh_filesize(path);
+
 	if(!ftp->has_size_command)
 		return -1;
 	if(ftp_type(tmBinary) != 0)
@@ -1181,8 +1282,12 @@ rdirectory *ftp_read_directory(const char *path)
 	bool is_curdir = false;
 	char *tmpfilename, *e;
 	bool _failed = false;
+	char *dir;
 
-	char *dir = ftp_path_absolute(path);
+	if(ftp->ssh_pid)
+		return ssh_read_directory(path);
+
+	dir = ftp_path_absolute(path);
 	stripslash(dir);
 
 	is_curdir = (strcmp(dir, ftp->curdir) == 0);
@@ -1278,6 +1383,7 @@ rfile *ftp_get_file(const char *path)
 		return 0;
 
 	ap = ftp_path_absolute(path);
+	stripslash(ap);
 
 	f = ftp_cache_get_file(ap);
 	if(!f) {
@@ -1285,7 +1391,7 @@ rfile *ftp_get_file(const char *path)
 		rdirectory *rdir = ftp_get_directory(p);
 		xfree(p);
 		if(rdir)
-			f = rdir_get_file(rdir, base_name_ptr(path));
+			f = rdir_get_file(rdir, base_name_ptr(ap));
 	}
 	xfree(ap);
 	return f;
@@ -1301,7 +1407,7 @@ static bool ftp_path_part_of(const char *a, const char *b)
 		return false;
 
 	alen = strlen(a);
-	
+
 	/* see if a and b are equal to the length of a */
 	if(strncmp(a, b, alen) == 0) {
 		/* see if the last directory in b is complete */
@@ -1328,7 +1434,7 @@ int ftp_mkpath(const char *path)
 
 	if(!path)
 		return 0;
-	
+
 	/* check if we already has created this path */
 	if(ftp_path_part_of(path, ftp->last_mkpath))
 		return 0;
@@ -1360,7 +1466,7 @@ int ftp_mkpath(const char *path)
 		xfree(e);
 		e = foo;
 
-	
+
 		/* check if we already has created this path */
 		if(ftp_path_part_of(e, ftp->last_mkpath))
 			continue;
@@ -1396,6 +1502,9 @@ void ftp_flush_reply(void)
 	if(!ftp_connected())
 		return;
 
+	if(ftp->ssh_pid)
+		return;
+
 /*	ftp_set_signal(SIGINT, SIG_IGN);*/
 	fprintf(stderr, "flushing replies...\r");
 
@@ -1423,6 +1532,9 @@ int ftp_rename(const char *oldname, const char *newname)
 	char *on;
 	char *nn;
 
+	if(ftp->ssh_pid)
+		return ssh_rename(oldname, newname);
+
 	on = xstrdup(oldname);
 	stripslash(on);
 	ftp_cmd("RNFR %s", on);
@@ -1543,6 +1655,10 @@ time_t ftp_filetime(const char *filename)
 
 	if(!ftp_connected())
 		return -1;
+
+	if(ftp->ssh_pid)
+		return ssh_filetime(filename);
+
 	if(!ftp->has_mdtm_command)
 		return -1;
 
@@ -1587,3 +1703,12 @@ int ftp_maybe_isdir(rfile *fp)
 	}
 	return 0;
 }
+
+void ftp_pwd(void)
+{
+	if(ftp->ssh_pid)
+		return ssh_pwd();
+
+	ftp_set_tmp_verbosity(vbCommand);
+	ftp_cmd("PWD");
+}
