@@ -1,21 +1,14 @@
-/* ftpsend.c -- send/receive files and file listings
+/* $Id: ftpsend.c,v 1.9 2001/05/12 18:44:04 mhe Exp $
  *
- * This file is part of Yafc, an ftp client.
- * This program is Copyright (C) 1998-2001 martin HedenfaLk
+ * ftpsend.c -- send/receive files and file listings
+ *
+ * Yet Another FTP Client
+ * Copyright (C) 1998-2001, Martin Hedenfalk <mhe@stacken.kth.se>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * (at your option) any later version. See COPYING for more details.
  */
 
 #include "syshdr.h"
@@ -25,6 +18,7 @@
 #include "xmalloc.h"
 #include "ftpsigs.h"
 #include "gvars.h"
+#include "ssh_cmd.h"
 
 static int ftp_pasv(unsigned char result[6])
 {
@@ -115,9 +109,13 @@ static int ftp_init_transfer(void)
 
 int ftp_type(transfer_mode_t type)
 {
+	if(ftp->ssh_pid)
+		/* FIXME: is this relevant for ssh ? */
+		return 0;
+
 	if(type == tmCurrent)
 		return 0;
-	
+
 	if(ftp->prev_type != type) {
 		ftp_cmd("TYPE %c", type == tmAscii ? 'A' : 'I');
 		if(ftp->code != ctComplete)
@@ -137,6 +135,10 @@ int ftp_abort(FILE *fp)
 	fd_set ready;
 	struct timeval poll;
 
+	if(ftp->ssh_pid)
+		/* FIXME: what? */
+		return 0;
+
 	if(!ftp_connected())
 		return -1;
 
@@ -505,7 +507,7 @@ static int FILE_send_ascii(FILE *in, FILE *out)
 	return maybe_abort(in, out);
 }
 
-static void reset_transfer_info(void)
+void reset_transfer_info(void)
 {
 	ftp->ti.barelfs = 0;
 	ftp->ti.size = 0L;
@@ -528,6 +530,9 @@ int ftp_list(const char *cmd, const char *param, FILE *fp)
 	if(!cmd || !fp || !ftp_connected())
 		return -1;
 
+	if(ftp->ssh_pid)
+		return ssh_list(cmd, param, fp);
+
 	reset_transfer_info();
 	foo_hookf = 0;
 
@@ -561,14 +566,15 @@ int ftp_list(const char *cmd, const char *param, FILE *fp)
 	return ftp->code == ctComplete ? 0 : -1;
 }
 
-static void transfer_finished(void)
+void transfer_finished(void)
 {
 	ftp->ti.finished = true;
 	if(foo_hookf)
 		foo_hookf(&ftp->ti);
 }
 
-int ftp_init_receive(const char *path, transfer_mode_t mode, ftp_transfer_func hookf)
+static int ftp_init_receive(const char *path, transfer_mode_t mode,
+							ftp_transfer_func hookf)
 {
 	long rp = ftp->restart_offset;
 	char *e;
@@ -611,7 +617,7 @@ int ftp_init_receive(const char *path, transfer_mode_t mode, ftp_transfer_func h
 			/* try to figure out file size from RETR reply
 			 * Opening BINARY mode data connection for foo.mp3 (14429793 bytes)
 			 *                                                  ^^^^^^^^ aha!
-			 * 
+			 *
 			 * note: this might not be the _total_ filesize if we are RESTarting
 			 */
 			e = strstr(ftp->reply, " bytes");
@@ -625,8 +631,8 @@ int ftp_init_receive(const char *path, transfer_mode_t mode, ftp_transfer_func h
 	return 0;
 }
 
-int ftp_do_receive(FILE *fp,
-				   transfer_mode_t mode, ftp_transfer_func hookf)
+static int ftp_do_receive(FILE *fp,
+						  transfer_mode_t mode, ftp_transfer_func hookf)
 {
 	int r;
 
@@ -655,14 +661,17 @@ int ftp_do_receive(FILE *fp,
 int ftp_receive(const char *path, FILE *fp,
 				transfer_mode_t mode, ftp_transfer_func hookf)
 {
+	if(ftp->ssh_pid)
+		return ssh_do_receive(path, fp, mode, hookf);
+
 	if(ftp_init_receive(path, mode, hookf) != 0)
 		return -1;
 
 	return ftp_do_receive(fp, mode, hookf);
 }
 
-int ftp_send(const char *path, FILE *fp, putmode_t how,
-			 transfer_mode_t mode, ftp_transfer_func hookf)
+static int ftp_send(const char *path, FILE *fp, putmode_t how,
+					transfer_mode_t mode, ftp_transfer_func hookf)
 {
 	int r;
 	long rp = ftp->restart_offset;
@@ -671,7 +680,6 @@ int ftp_send(const char *path, FILE *fp, putmode_t how,
 	if(how == putUnique && !ftp->has_stou_command)
 		return -1;
 
-	foo_hookf = hookf;
 	reset_transfer_info();
 	ftp->ti.transfer_is_put = true;
 
@@ -704,7 +712,7 @@ int ftp_send(const char *path, FILE *fp, putmode_t how,
 		ftp_cmd("STOR %s", path);
 		break;
 	}
-	
+
 	if(ftp->code != ctPrelim)
 		return -1;
 
@@ -721,7 +729,8 @@ int ftp_send(const char *path, FILE *fp, putmode_t how,
 					ftp->ti.local_name = xstrndup(e+1, l-3);
 				else
 					ftp->ti.local_name = xstrndup(e, l-1);
-				ftp_trace("parsed unique filename as '%s'\n", ftp->ti.local_name);
+				ftp_trace("parsed unique filename as '%s'\n",
+						  ftp->ti.local_name);
 			}
 		}
 	}
@@ -769,12 +778,17 @@ int ftp_fxpfile(Ftp *srcftp, const char *srcfile,
 	unsigned char addr[6];
 
 	printf("FxP: %s -> %s\n", srcftp->url->hostname, destftp->url->hostname);
-	
+
 	if(srcftp == destftp) {
 		ftp_err(_("FxP between same hosts\n"));
 		return -1;
 	}
 
+	if(ftp->ssh_pid) {
+		ftp_err("FxP with SSH not implemented\n");
+		return -1;
+	}
+
 	thisftp = ftp; /* save currently active connection */
 
 	/* setup source side */
@@ -808,7 +822,8 @@ int ftp_fxpfile(Ftp *srcftp, const char *srcfile,
 		else {
 			ftp->restart_offset = ftp_filesize(destfile);
 			if(ftp->restart_offset == (unsigned long)-1) {
-				ftp_err(_("unable to get remote filesize of '%s', unable to resume\n"),
+				ftp_err(_("unable to get remote filesize of '%s',"
+						  " unable to resume\n"),
 						destfile);
 				ftp->restart_offset = 0L;
 			}
@@ -826,7 +841,7 @@ int ftp_fxpfile(Ftp *srcftp, const char *srcfile,
 		if(ftp->code != ctContinue)
 			return -1;
 	}
-	
+
 	/* issue a STOR command on DESTFTP */
 	ftp_use(destftp);
 	switch(how) {
@@ -911,7 +926,8 @@ int ftp_getfile(const char *infile, const char *outfile, getmode_t how,
 	/* we need to save this, because ftp_init_receive() sets it to zero */
 	rp = ftp->restart_offset;
 
-	if(ftp_init_receive(infile, mode, hookf) != 0)
+	reset_transfer_info();
+	if(!ftp->ssh_pid && ftp_init_receive(infile, mode, hookf) != 0)
 		return -1;
 
 	if(how == getPipe) {
@@ -924,13 +940,16 @@ int ftp_getfile(const char *infile, const char *outfile, getmode_t how,
 	}
 	if(!fp) {
 		ftp_err("%s: %s\n", outfile, strerror(errno));
+		ftp->restart_offset = 0L;
 		return -1;
 	}
 
 	if(rp > 0L) {
 		if(fseek(fp, rp, SEEK_SET) != 0) {
-			ftp_err(_("%s: %s, transfer cancelled\n"), outfile, strerror(errno));
+			ftp_err(_("%s: %s, transfer cancelled\n"),
+					outfile, strerror(errno));
 			close_func(fp);
+			ftp->restart_offset = 0L;
 			return -1;
 		}
 	}
@@ -940,7 +959,12 @@ int ftp_getfile(const char *infile, const char *outfile, getmode_t how,
 	ftp->ti.remote_name = xstrdup(infile);
 	ftp->ti.local_name = xstrdup(outfile);
 
-	r = ftp_do_receive(fp, mode, hookf);
+	foo_hookf = hookf;
+
+	if(ftp->ssh_pid)
+		r = ssh_do_receive(infile, fp, mode, hookf);
+	else
+		r = ftp_do_receive(fp, mode, hookf);
 	close_func(fp);
 	return r;
 }
@@ -983,7 +1007,8 @@ int ftp_putfile(const char *infile, const char *outfile, putmode_t how,
 		else {
 			ftp->restart_offset = ftp_filesize(outfile);
 			if(ftp->restart_offset == (unsigned long)-1) {
-				ftp_err(_("unable to get remote filesize of '%s', unable to resume\n"),
+				ftp_err(_("unable to get remote filesize of '%s',"
+						  " unable to resume\n"),
 						outfile);
 				ftp->restart_offset = 0L;
 			}
@@ -991,17 +1016,22 @@ int ftp_putfile(const char *infile, const char *outfile, putmode_t how,
 	} else
 		ftp->restart_offset = 0L;
 
-	
+
 	if(ftp->restart_offset > 0L) {
 		if(fseek(fp, ftp->restart_offset, SEEK_SET) != 0) {
-			ftp_err(_("%s: %s, transfer cancelled\n"), outfile, strerror(errno));
+			ftp_err(_("%s: %s, transfer cancelled\n"),
+					outfile, strerror(errno));
 			fclose(fp);
 			return -1;
 		}
 	}
 
+	foo_hookf = hookf;
 
-	r = ftp_send(outfile, fp, how, mode, hookf);
+	if(ftp->ssh_pid)
+		r = ssh_send(outfile, fp, how, mode, hookf);
+	else
+		r = ftp_send(outfile, fp, how, mode, hookf);
 	fclose(fp);
 	return r;
 }
