@@ -1,21 +1,14 @@
-/* rfile.c -- representation of a remote file
+/* $Id: rfile.c,v 1.5 2001/05/13 13:26:32 mhe Exp $
  *
- * This file is part of Yafc, an ftp client.
- * This program is Copyright (C) 1998-2001 martin HedenfaLk
+ * rfile.c -- representation of a remote file
+ *
+ * Yet Another FTP Client
+ * Copyright (C) 1998-2001, Martin Hedenfalk <mhe@stacken.kth.se>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * (at your option) any later version. See COPYING for more details.
  */
 
 #include "syshdr.h"
@@ -195,7 +188,7 @@ static const char *month_name[] = {
 /* returns month number if STR is a month abbreviation
  * else -1
  */
-static int month_number(const char *str)
+int month_number(const char *str)
 {
 	int i;
 
@@ -210,7 +203,7 @@ void rfile_parse_time(rfile *f, const char *m, const char *d, const char *y)
 {
 	struct tm mt;
 	int u;
-	
+
 	f->mtime = (time_t)-1;
 
 	if(!m || !d || !y)
@@ -276,11 +269,35 @@ if(!e || !*e) { \
     return -1; \
 }
 
+char *time_to_string(time_t t)
+{
+	char *ret;
+	time_t now;
+	char *fmt;
+
+	now = time(0);
+	if(now > t + 6L * 30L * 24L * 60L * 60L  /* Old. */
+	   || now < t - 60L * 60L)   /* In the future. */
+		{
+			/* The file is fairly old or in the future.
+			   POSIX says the cutoff is 6 months old;
+			   approximate this by 6*30 days.
+			   Allow a 1 hour slop factor for what is considered "the future",
+			   to allow for NFS server/client clock disagreement.
+			   Show the year instead of the time of day.  */
+			fmt = "%b %e  %Y";
+		}
+	else
+		fmt = "%b %e %H:%M";
+	ret = (char *)xmalloc(42);
+	strftime(ret, 42, fmt, localtime(&t));
+
+	return ret;
+}
+
 static int rfile_parse_eplf(rfile *f, char *str, const char *dirpath)
 {
-	time_t current_time;
 	char *e;
-	char *fmt;
 
 	if(!str || str[0] != '+')
 		return -1;
@@ -305,22 +322,7 @@ static int rfile_parse_eplf(rfile *f, char *str, const char *dirpath)
 		case 'm':
 			f->mtime = strtoul(e+1, 0, 10);
 			xfree(f->date);
-			current_time = time(0);
-			if (current_time > f->mtime + 6L * 30L * 24L * 60L * 60L  /* Old. */
-		        || current_time < f->mtime - 60L * 60L)   /* In the future. */
-				{
-					/* The file is fairly old or in the future.
-					   POSIX says the cutoff is 6 months old;
-					   approximate this by 6*30 days.
-					   Allow a 1 hour slop factor for what is considered "the future",
-					   to allow for NFS server/client clock disagreement.
-					   Show the year instead of the time of day.  */
-					fmt = "%b %e  %Y";
-				}
-			else
-				fmt = "%b %e %H:%M";
-			f->date = (char *)xmalloc(42);
-			strftime(f->date, 42, fmt, localtime(&f->mtime));
+			f->date = time_to_string(f->mtime);
 			break;
 		case 's':
 			f->size = strtoul(e+1, 0, 10);
@@ -346,29 +348,29 @@ static int rfile_parse_unix(rfile *f, char *str, const char *dirpath)
 	char *saved_field[5];
 
 	/* real unix ls listing:
-	 * 
+	 *
 	 * saved_field[0] == nhl
 	 * saved_field[1] == owner
 	 * saved_field[2] == group
 	 * saved_field[3] == size
 	 * saved_field[4] == month
-	 * 
+	 *
 	 * unix w/o group listing:
-	 * 
+	 *
 	 * saved_field[0] == nhl
 	 * saved_field[1] == owner
 	 * saved_field[2] == size
 	 * saved_field[3] == month
 	 * saved_field[4] == date
-	 * 
+	 *
 	 * strange MacOS WebStar thingy:
-	 * 
+	 *
 	 * saved_field[0] == size or "folder"
 	 * saved_field[1] == zero or date if [0]=="folder"
 	 * saved_field[2] == size (again!?) or month
 	 * saved_field[3] == month or date
 	 * saved_field[4] == date or time (or year?)
-	 * 
+	 *
 	 */
 
 	if(strncmp(str, "total ", 6) == 0)
@@ -408,8 +410,8 @@ static int rfile_parse_unix(rfile *f, char *str, const char *dirpath)
 	/* distinguish the different ls variants by looking
 	 * for the month field
 	 */
-	
-	if(month_number(saved_field[4]) != -1) 
+
+	if(month_number(saved_field[4]) != -1)
 	{
 		/* ls -l */
 		f->nhl = atoi(saved_field[0]);
@@ -474,9 +476,9 @@ static int rfile_parse_unix(rfile *f, char *str, const char *dirpath)
 	}
 
 	/* ftp.apple.com:
-	 * 
+	 *
 	 * drwxr-xr-x   8 0        system       512 Jan  1 22:51 dts
-	 * d--x--x--x   2 0        system       512 Sep 12 1997  etc 
+	 * d--x--x--x   2 0        system       512 Sep 12 1997  etc
 	 *                                             --------^
 	 * doesn't pad year, so assume filename doesn't start with a space
 	 */
@@ -509,7 +511,7 @@ static int rfile_parse_dos(rfile *f, char *str, const char *dirpath)
 
 	if(y < 70)
 		y += 100;
-	
+
 	NEXT_FIELD;
 	if(sscanf(e, "%d:%2d%2s", &h, &mm, ampm) != 3)
 		return -1;
