@@ -1,21 +1,14 @@
-/* input.c -- string input and readline stuff
- * 
- * This file is part of Yafc, an ftp client.
- * This program is Copyright (C) 1998-2001 martin HedenfaLk
- * 
+/* $Id: input.c,v 1.5 2001/05/13 11:50:17 mhe Exp $
+ *
+ * input.c -- string input and readline stuff
+ *
+ * Yet Another FTP Client
+ * Copyright (C) 1998-2001, Martin Hedenfalk <mhe@stacken.kth.se>
+ *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- * 
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * (at your option) any later version. See COPYING for more details.
  */
 
 #include "syshdr.h"
@@ -85,7 +78,7 @@ int input_read_args(args_t **args, const char *prompt)
 	args_destroy(*args);
 	*args = args_create();
 
-#ifdef HAVE_LIBREADLINE
+#if (HAVE_LIBREADLINE >= 210)
 	rl_completion_append_character = ' ';
 #endif
 	e = input_read_string(prompt);
@@ -127,7 +120,7 @@ void input_init(void)
 	rl_outstream = stderr;
     /* Allow conditional parsing of the ~/.inputrc file. */
     rl_readline_name = PACKAGE;
-    rl_completion_entry_function = (Function *)no_completion_function;
+    rl_completion_entry_function = (rl_compentry_func_t *)no_completion_function;
     /* Tell the completer that we want a crack first. */
     rl_attempted_completion_function = (CPPFunction *)the_complete_function;
 
@@ -136,10 +129,10 @@ void input_init(void)
 #if (HAVE_LIBREADLINE >= 210)
 	/* characters that need to be quoted when appearing in filenames. */
 	rl_filename_quote_characters = " \t\n\\\"'@<>=;|&()#$`?*[]!:";
-#endif
 	rl_filename_quoting_function = bash_quote_filename;
-	rl_filename_dequoting_function = bash_dequote_filename;
+	rl_filename_dequoting_function = (rl_dequote_func_t *)bash_dequote_filename;
 	rl_char_is_quoted_p = char_is_quoted;
+#endif
 
 	force_completion_type = cpUnset;
 
