@@ -1,21 +1,14 @@
-/* args.h -- handles command arguments
+/* $Id: args.h,v 1.3 2001/05/12 18:43:01 mhe Exp $
  *
- * This file is part of Yafc, an ftp client.
- * This program is Copyright (C) 1998-2001 martin HedenfaLk
+ * args.h -- handles command arguments
+ *
+ * Yet Another FTP Client
+ * Copyright (C) 1998-2001, Martin Hedenfalk <mhe@stacken.kth.se>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * (at your option) any later version. See COPYING for more details.
  */
 
 #ifndef _args_h_included
@@ -32,19 +25,21 @@ void args_destroy(args_t *args);
 void args_clear(args_t *args);
 void args_init(args_t *args, int argc, char **argv);
 void args_init2(args_t *args, int argc, char **argv, unsigned int first);
-void args_init3(args_t *args, int argc, char **argv, unsigned int first, unsigned int last);
+void args_init3(args_t *args, int argc, char **argv, unsigned int first,
+				unsigned int last);
 char *args_cat(int argc, char **argv, unsigned int first);
 char *args_cat2(const args_t *args, unsigned int first);
 void args_add_args(args_t *args, const args_t *add_args);
 void args_add_args2(args_t *args, const args_t *add_args, unsigned int first);
-void args_add_args3(args_t *args, const args_t *add_args, unsigned int first, unsigned int last);
+void args_add_args3(args_t *args, const args_t *add_args, unsigned int first,
+					unsigned int last);
 void args_del(args_t *args, unsigned int first, unsigned int n);
 void args_push_back(args_t *args, const char *str);
 void args_push_front(args_t *args, const char *str);
 void args_remove_empty(args_t *args);
 void args_unquote(args_t *args);
 void args_insert_string(args_t *args, unsigned int index, const char *str);
-void args_insert_args(args_t *args, unsigned int index,
-					  const args_t *insargs, unsigned int first, unsigned int last);
+void args_insert_args(args_t *args, unsigned int index, const args_t *insargs,
+					  unsigned int first, unsigned int last);
 
 #endif
