@@ -1,21 +1,14 @@
-/* list.c -- the remote cached 'ls' command
- * 
- * This file is part of Yafc, an ftp client.
- * This program is Copyright (C) 1998-2001 martin HedenfaLk
- * 
+/* $Id: list.c,v 1.7 2001/05/12 18:44:37 mhe Exp $
+ *
+ * list.c -- the remote cached 'ls' command
+ *
+ * Yet Another FTP Client
+ * Copyright (C) 1998-2001, Martin Hedenfalk <mhe@stacken.kth.se>
+ *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- * 
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * (at your option) any later version. See COPYING for more details.
  */
 
 #include "syshdr.h"
@@ -46,6 +39,7 @@
 #define LS_LITERAL (1 << 17)
 #define LS_WPATH (1 << 18)
 #define LS_HUMAN_READABLE (1 << 19)
+#define LS_SORT_NAME (1 << 20)
 
 static void print_ls_syntax(void)
 {
@@ -261,7 +255,7 @@ static void ls_wide(list *gl, unsigned opt, bool doclr)
 				}
 				if(br)
 					break;
-			
+
 				while(left--)
 					putchar(' ');
 			}
@@ -293,7 +287,7 @@ static int ls_sort_dirs(rfile *a, rfile *b)
 		return 1;
 	return 0;
 }
-	
+
 static int ls_sort_size(rfile *a, rfile *b)
 {
 	if(a->size > b->size)
@@ -332,12 +326,19 @@ static int ls_sort_mtime(rfile *a, rfile *b)
 	return 0;
 }
 
+static int ls_sort_name(rfile *a, rfile *b)
+{
+	return strcmp(a->path, b->path);
+}
+
 static void ls_all(list *gl, unsigned opt, bool doclr)
 {
 	if(list_numitem(gl) == 0)
 		return;
 
-	if(test(opt, LS_SORT_DIRS_FIRST))
+	if(test(opt, LS_SORT_NAME))
+		list_sort(gl, (listsortfunc)ls_sort_name, test(opt, LS_SORT_REVERSE));
+	else if(test(opt, LS_SORT_DIRS_FIRST))
 		list_sort(gl, (listsortfunc)ls_sort_dirs, test(opt, LS_SORT_REVERSE));
 	else if(test(opt, LS_SORT_SIZE))
 		list_sort(gl, (listsortfunc)ls_sort_size, test(opt, LS_SORT_REVERSE));
@@ -420,6 +421,8 @@ void cmd_ls(int argc, char **argv)
 		{0, 0, 0, 0},
 	};
 
+	opt |= LS_SORT_NAME;
+
 	optind = 0; /* force getopt() to re-initialize */
 	while((c = getopt_long(argc, argv, "aAFCdGhlNogBrRStUxX12",
 						   longopts, NULL)) != EOF) {
@@ -468,7 +471,7 @@ void cmd_ls(int argc, char **argv)
 			opt &= ~(LS_SORT_EXT | LS_SORT_DIRS_FIRST | LS_SORT_MTIME);
 			break;
 		  case 'U':
-			opt &= ~(LS_SORT_SIZE | LS_SORT_EXT
+			opt &= ~(LS_SORT_NAME | LS_SORT_SIZE | LS_SORT_EXT
 					 | LS_SORT_DIRS_FIRST | LS_SORT_MTIME);
 			break;
 		  case 'x':
@@ -527,7 +530,7 @@ void cmd_ls(int argc, char **argv)
 		 * if dir, append '*' and glob, else glob that file
 		 * if not listing directory contents just glob that file
 		 */
-		
+
 		while(optind < argc) {
 			char *e, *f;
 			bool isdir = false;
@@ -539,13 +542,19 @@ void cmd_ls(int argc, char **argv)
 					*f = 0; /* we'll put it back below */
 					isdir = true;
 				} else {
+					rdirectory *rdir;
 					rfile *rf;
 					char *q = xstrdup(e);
 					unquote(q);
-					rf = ftp_get_file(q);
-					xfree(q);
-					if(rf && ftp_maybe_isdir(rf) == 1)
+					rdir = ftp_get_directory(q);
+					if(rdir)
 						isdir = true;
+					else {
+						rf = ftp_get_file(q);
+						xfree(q);
+						if(rf && ftp_maybe_isdir(rf) == 1)
+							isdir = true;
+					}
 				}
 			} else
 				/* prevent rglob_glob() from appending "*" */
