@@ -1,21 +1,14 @@
-/* main.c -- parses command line options and starts Yafc
+/* $Id: main.c,v 1.15 2001/05/13 14:36:26 mhe Exp $
  *
- * This file is part of Yafc, an ftp client.
- * This program is Copyright (C) 1998-2001 martin HedenfaLk
+ * main.c -- parses command line options and starts Yafc
+ *
+ * Yet Another FTP Client
+ * Copyright (C) 1998-2001, Martin Hedenfalk <mhe@stacken.kth.se>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * (at your option) any later version. See COPYING for more details.
  */
 
 #include "syshdr.h"
@@ -143,7 +136,9 @@ void init_yafc(void)
 		gvWorkingDirectory ? gvWorkingDirectory : "~/.yafc",
 		get_local_curdir(),
 		gvLocalHomeDir);
-	
+
+	gvSSHProgram = xstrdup("/usr/bin/ssh");
+
 	gvAnonPasswd = getenv("EMAIL");
 	if(gvAnonPasswd)
 		gvAnonPasswd = xstrdup(gvAnonPasswd);
@@ -166,7 +161,7 @@ void init_yafc(void)
 #else
 	listify_string("none", gvDefaultMechanism);
 #endif
-	
+
 	gvPrompt1 = xstrdup("yafc> ");
 	gvPrompt2 = xstrdup("yafc %h> ");
 	gvPrompt3 = xstrdup("yafc %h:%42~> ");
@@ -189,9 +184,10 @@ void init_yafc(void)
 	ftp_set_signal(SIGTSTP, tstp_sighandler);
 	ftp_set_signal(SIGCONT, tstp_sighandler);
 
-	gvTransferBeginString = 0;
-	gvTransferString = xstrdup("%-40R %s/%S ETA %e %B");
-	gvTransferEndString = xstrdup("%-40R      %s in %t @ %b\n");
+	gvTransferBeginString = xstrdup("%-70R\n");
+	gvTransferString = xstrdup("%5p%% [%25v] %s/%S ETA %e %B");
+/*	gvTransferEndString = xstrdup("%-40R      %s in %t @ %b\n");*/
+
 	gvTransferXtermString = xstrdup("\e]0;yafc - (%p%%) %r\x07");
 
 	input_init();
@@ -299,7 +295,7 @@ int main(int argc, char **argv, char **envp)
 #ifdef SOCKS
 	SOCKSinit(argv[0]);
 #endif
-	
+
 #ifdef ENABLE_NLS
 # ifdef HAVE_SETLOCALE
 	setlocale(LC_ALL, "");
@@ -310,7 +306,7 @@ int main(int argc, char **argv, char **envp)
 #if 0 && (!defined(HAVE_SETPROCTITLE) && defined(linux))
 	initsetproctitle(argc, argv, envp);
 #endif
-	
+
 	while((c = getopt_long(argc, argv,
 						   "qhdDgant::r:uUm:pvVw:W:", longopts, 0)) != EOF)
 	{
